@@ -20,6 +20,8 @@ my %defs =
 				 'has_join_restriction',
 				 'restriction_is_constant_false',
 				 'build_child_join_sjinfo',
+				 'get_matching_part_pairs',
+				 'compute_partition_bounds',
 				 'try_partitionwise_join'],
 	   head => core_c_head()},
    'make_join_rel.c'
@@ -160,6 +162,8 @@ sub core_c_head()
  *     has_join_restriction()
  *     restriction_is_constant_false()
  *     build_child_join_sjinfo()
+ *     get_matching_part_pairs()
+ *     compute_partition_bounds()
  *     try_partitionwise_join()
  *
  * Portions Copyright (c) 1996-2020, PostgreSQL Global Development Group
